==> charlatan_0.5.1.tar.gz: charlatan/R/jobs-provider-hr_HR.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/hr_HR/__init__.py

job_formats_hr_hr <- c(
  "Agent posredovanja u prometu nekretnina",
  "Alatni\u010dar",
  "Arhivist",
  "Arhivski savjetnik",
  "Arhivski tehni\u010dar",
  "Autoelektri\u010dar",
  "Autolakirer",
  "Autolimar",
  "Automehani\u010dar",
  "Autoserviser",
  "Bravar",
  "Brodostrojarski inspektor",
  "Brodski mehani\u010dar",
  "Dentalni asistent",
  "Dentalni tehni\u010dar",
  "Dimnja\u010dar",
  "Diplomirana medicinska sestra/medicinski tehni\u010dar",
  "Diplomirani fizioterapeut",
  "Diplomirani knji\u017eni\u010dar",
  "Diplomirani sanitarni in\u017eenjer",
  "Direktor predstavni\u0161tva",
  "Direktor turisti\u010dkog ureda turisti\u010dke zajednice",
  "Dispe\u010der leta / operativni kontrolor prometa",
  "Djelatnik koji obavlja poslove izvo\u0111enja glasnog pucnja",
  "Djelatnik koji obavlja poslove izvo\u0111enja javnog vatrometa",
  "Djelatnik koji obavlja poslove miniranja",
  "Djelatnik koji obavlja poslove miniranja pri razminiranju",
  "Djelatnik koji obavlja poslove podzemnih miniranja",
  "Djelatnik koji obavlja poslove pripreme miniranja",
  "Djelatnik koji obavlja poslove specijalnih miniranja",
  "Djelatnik slu\u017ebe za za\u0161titu od po\u017eara",
  "Djelatnik za obavljanje poslova za\u0161tite od po\u017eara i unapre\u0111enje stanja za\u0161tite od po\u017eara",
  "Doktor dentalne medicine",
  "Doktor dentalne medicine specijalist",
  "Doktor medicine",
  "Doktor medicine specijalist",
  "Dokumentarist",
  "Dokumentarist savjetnik",
  "Do\u010dasnik",
  "Edukacijski rehabilitator",
  "Elektroinstalater",
  "Elektromehani\u010dar",
  "Elektroni\u010dar \u2013 mehani\u010dar",
  "Farmaceutski tehni\u010dar",
  "Fasader",
  "Fizioterapeutski tehni\u010dar",
  "Fotograf",
  "Frizer",
  "Galanterist",
  "Geolo\u0161ki tehni\u010dar",
  "Glavni inspektor za\u0161tite okoli\u0161a",
  "Glavni nadzornik",
  "Glazbalar",
  "Graditelj brodova",
  "Graditelj orgulja",
  "Hidrogra\u0111evinski\u00a0 inspektor",
  "Informati\u010dar",
  "Informati\u010dar savjetnik",
  "Inspektor sigurnosti unutarnje plovidbe",
  "Inspektor za\u0161tite okoli\u0161a",
  "Inspektor za\u0161tite prirode",
  "Instalater grijanja i klimatizacije",
  "Instruktor vo\u017enje",
  "In\u017eenjer geologije",
  "In\u017eenjer gradili\u0161ta",
  "In\u017eenjer medicinske radiologije",
  "In\u017eenjer medicinsko- laboratorijske dijagnostike",
  "In\u017eenjer naftnog rudarstva",
  "In\u017eenjer rudarstva",
  "Kemijski \u010dista\u010d",
  "Klesar",
  "Klobu\u010dar",
  "Knji\u017eni\u010dar",
  "Knji\u017eni\u010darski savjetnik",
  "Kondukter",
  "Kontrolor zra\u010dnog prometa",
  "Konzervator",
  "Konzervator savjetnik",
  "Konzervator tehni\u010dar",
  "Konzervator \u2013 restaurator savjetnik",
  "Konzervator \u2013\u00a0 restaurator",
  "Koordinator za\u0161tite na radu",
  "Kormilar",
  "Kotlar",
  "Kova\u010d",
  "Kozmeti\u010dar",
  "Kriminalist",
  "Kroja\u010d mu\u0161ke odje\u0107e",
  "Kroja\u010d \u017eenske odje\u0107e",
  "Krovopokriva\u010d",
  "Krznar",
  "Kuhar",
  "Kustos",
  "Lektor hrvatskog jezika na stranim visoko\u0161kolskim ustanovama",
  "Limar",
  "Ljekarnik",
  "Ljekarnik specijalist",
  "Ljeva\u010d",
  "Lovac",
  "Lovo\u010duvar",
  "Magistar sanitarnog in\u017eenjerstva",
  "Magistar sestrinstva",
  "Maser \u2013 kupeljar",
  "Medicinska sestra op\u0107e njege",
  "Medicinska sestra-medicinski tehni\u010dar",
  "Medicinska sestra/medicinski tehni\u010dar specijalist",
  "Medicinski biokemi\u010dar",
  "Medicinski biokemi\u010dar specijalist",
  "Mehani\u010dar poljoprivredne mehanizacije",
  "Mesar",
  "Mlinar",
  "Mljekar",
  "Mornar",
  "Muzejski pedagog",
  "Muzejski pedagog savjetnik",
  "Muzejski savjetnik",
  "Muzejski tehni\u010dar",
  "Nadzornik",
  "Nadzornik tehni\u010dke ispravnosti vozila",
  "Nadzornik za okoli\u0161",
  "Nastavnik predmetne nastave u srednjoj \u0161koli",
  "Natkonobar",
  "Nauti\u010dki inspektor",
  "Obu\u0107ar",
  "Ocjenjiva\u010d lova\u010dkih trofeja",
  "Odgajatelj u u\u010deni\u010dkom domu",
  "Odgojitelj djece pred\u0161kolske dobi",
  "Odgovorna osoba za ocjenjivanje sukladnosti gra\u0111evinskih proizvoda",
  "Odvjetnik",
  "Ortopedski obu\u0107ar",
  "Osoba koja provodi energetske preglede gra\u0111evina i/ili energetsko certificiranje zgrada",
  "Osoba stru\u010dno osposobljena za gospodarski ribolov",
  "Osoba stru\u010dno osposobljena za obavljanje akvakulture",
  "Osoba stru\u010dno osposobljena za uzgoj riba i drugih morskih organizama",
  "Osoblje za odr\u017eavanje\u00a0 zrakoplova (mehani\u010dari, tehni\u010dari i in\u017eenjeri)",
  "Ovla\u0161tena osoba za izradu elaborata za\u0161tite od po\u017eara",
  "Ovla\u0161teni arhitekt",
  "Ovla\u0161teni arhitekt \u2013 urbanist",
  "Ovla\u0161teni carinski slu\u017ebenik",
  "Ovla\u0161teni carinski zastupnik",
  "Ovla\u0161teni in\u017eenjer drvne tehnologije",
  "Ovla\u0161teni in\u017eenjer elektrotehnike",
  "Ovla\u0161teni in\u017eenjer geodezije",
  "Ovla\u0161teni in\u017eenjer gra\u0111evinarstva",
  "Ovla\u0161teni in\u017eenjer strojarstva",
  "Ovla\u0161teni in\u017eenjer tehnologije prometa i transporta",
  "Ovla\u0161teni in\u017eenjer \u0161umarstva",
  "Ovla\u0161teni ispitiva\u010d",
  "Ovla\u0161teni revident iz za\u0161tite od po\u017eara",
  "Ovla\u0161teni revizor",
  "Ovla\u0161teni unutarnji revizor za javni sektor",
  "O\u010dni opti\u010dar",
  "Pediker",
  "Pekar",
  "Pe\u0107ar",
  "Pirotehni\u010dar",
  "Pirotehni\u010dki nadglednik",
  "Pirotehni\u010dki nadzornik",
  "Pismoslikar",
  "Plinoinstalater",
  "Policajac",
  "Pomo\u0107ni djelatnik",
  "Pomo\u0107ni knji\u017eni\u010dar",
  "Pomo\u0107nik strojovo\u0111e",
  "Porezni savjetnik",
  "Precizni mehani\u010dar",
  "Predava\u010d",
  "Pregleda\u010d vagona",
  "Preparator",
  "Primalja",
  "Primalja \u2013 asistentica",
  "Privatni detektiv",
  "Profesionalni diplomat",
  "Profesionalni pilot aviona",
  "Profesionalni pilot helikoptera",
  "Prometni pilot aviona",
  "Prometni pilot helikoptera",
  "Prometnik vlakova",
  "Prvostupnik fizioterapije",
  "Prvostupnik medicinske radiologije",
  "Prvostupnik medicinsko- laboratorijske dijagnostike",
  "Prvostupnik primaljstva",
  "Prvostupnik radiolo\u0161ke tehnologije",
  "Prvostupnik radne terapije",
  "Prvostupnik sanitarnog in\u017eenjerstva",
  "Prvostupnik sestrinstva",
  "Prvostupnik sestrinstva specijalist",
  "Psiholog",
  "Pu\u0161kar",
  "Radio inspektor sigurnosti plovidbe",
  "Radiolo\u0161ki tehni\u010dar",
  "Radnik na stru\u010dnim poslovima na izvr\u0161enju zada\u0107a turisti\u010dke zajednice",
  "Radnik zaposlen na rukovode\u0107im poslovima",
  "Ravnatelj ustanove za pred\u0161kolski odgoj i naobrazbu",
  "Ravnatelj \u0161kolske ustanove",
  "Referent za poslove registracije vozila",
  "Restaurator",
  "Restaurator majstor",
  "Restaurator savjetnik",
  "Restaurator tehni\u010dar",
  "Revident",
  "Rudarski tehni\u010dar",
  "Rukovatelj eksplozivnim tvarima",
  "Rukovoditelj tehni\u010dkog plovila",
  "Sanitarni tehni\u010dar",
  "Sigurnosni savjetnik",
  "Slasti\u010dar",
  "Soboslikar \u2013 li\u010dilac",
  "Socijalni radnik",
  "Sportski trener",
  "Sportski u\u010ditelj / instruktor",
  "Sportski voditelj",
  "Staklar",
  "Stalni sudski procjenitelj",
  "Stalni sudski tuma\u010d",
  "Stalni sudski vje\u0161tak",
  "Stolar",
  "Strojar unutarnje plovidbe",
  "Strojobravar",
  "Strojovo\u0111a",
  "Strukovni u\u010ditelj u srednjoj \u0161koli",
  "Stru\u010dni radnik u djelatnosti socijalne skrbi",
  "Stru\u010dni radnik u ustanovi socijalne skrbi",
  "Stru\u010dni suradnik ovla\u0161tenog in\u017eenjera geodezije",
  "Stru\u010dni suradnik u pred\u0161kolskoj ustanovi",
  "Stru\u010dni suradnik u \u0161kolskoj ustanovi",
  "Stru\u010dni voditelj auto\u0161kole",
  "Stru\u010dnjak za\u0161tite na radu",
  "Suradnik ovla\u0161tenog in\u017eenjera geodezije",
  "Suradnik u nastavi",
  "Tapetar",
  "Tesar",
  "Tokar",
  "Turisti\u010dki pratitelj",
  "Turisti\u010dki vodi\u010d",
  "Upravitelj prijevoza (osoba odgovorna za prijevoz)",
  "Urar",
  "U\u010ditelj predmetne nastave u osnovnoj \u0161koli",
  "U\u010ditelj razredne nastave u osnovnoj \u0161koli",
  "U\u010ditelj stru\u010dnih predmeta",
  "Veterinar",
  "Veterinarski tehni\u010dar",
  "Vi\u0161i arhivist",
  "Vi\u0161i arhivski tehni\u010dar",
  "Vi\u0161i dokumentarist",
  "Vi\u0161i fotograf",
  "Vi\u0161i informati\u010dar",
  "Vi\u0161i inspektor",
  "Vi\u0161i inspektor cestovnog prometa i cesta",
  "Vi\u0161i inspektor za\u0161tite okoli\u0161a",
  "Vi\u0161i inspektor za\u0161tite prirode",
  "Vi\u0161i knji\u017eni\u010dar",
  "Vi\u0161i konzervator",
  "Vi\u0161i konzervator tehni\u010dar",
  "Vi\u0161i konzervator tehni\u010dar II stupnja",
  "Vi\u0161i konzervator \u2013\u00a0 restaurator",
  "Vi\u0161i kustos",
  "Vi\u0161i muzejski pedagog",
  "Vi\u0161i muzejski tehni\u010dar",
  "Vi\u0161i preparator",
  "Vi\u0161i restaurator",
  "Vi\u0161i restaurator tehni\u010dar",
  "Vlakovo\u0111a",
  "Voditelj ispostave",
  "Voditelj poslovnice turisti\u010dke agencije",
  "Voditelj projekta",
  "Voditelj radili\u0161ta",
  "Voditelj radova",
  "Voditelj skele u nacionalnoj plovidbi",
  "Vodoinstalater",
  "Vodoinstalater, instalater grijanja i klimatizacije",
  "Vojnik",
  "Voza\u010d teretnog motornog vozila i autobusa",
  "Vo\u0111a palube",
  "Zapovjednik plovila (vrsta A, vrsta B, vrsta C)",
  "Za\u0161titar",
  "Za\u0161titar-tehni\u010dar",
  "Zdravstveno laboratorijski tehni\u010dar",
  "Zidar",
  "Zlatar",
  "\u010casnik",
  "\u010clan kabinske posade zrakoplova",
  "\u010cuvar",
  "\u010cuvar prirode"
)

==> charlatan_0.6.1.tar.gz: charlatan/R/jobs-provider-hr_HR.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/hr_HR/__init__.py

job_formats_hr_hr <- c(
  "Agent posredovanja u prometu nekretnina",
  "Alatni\u010dar",
  "Arhivist",
  "Arhivski savjetnik",
  "Arhivski tehni\u010dar",
  "Autoelektri\u010dar",
  "Autolakirer",
  "Autolimar",
  "Automehani\u010dar",
  "Autoserviser",
  "Bravar",
  "Brodostrojarski inspektor",
  "Brodski mehani\u010dar",
  "Dentalni asistent",
  "Dentalni tehni\u010dar",
  "Dimnja\u010dar",
  "Diplomirana medicinska sestra/medicinski tehni\u010dar",
  "Diplomirani fizioterapeut",
  "Diplomirani knji\u017eni\u010dar",
  "Diplomirani sanitarni in\u017eenjer",
  "Direktor predstavni\u0161tva",
  "Direktor turisti\u010dkog ureda turisti\u010dke zajednice",
  "Dispe\u010der leta / operativni kontrolor prometa",
  "Djelatnik koji obavlja poslove izvo\u0111enja glasnog pucnja",
  "Djelatnik koji obavlja poslove izvo\u0111enja javnog vatrometa",
  "Djelatnik koji obavlja poslove miniranja",
  "Djelatnik koji obavlja poslove miniranja pri razminiranju",
  "Djelatnik koji obavlja poslove podzemnih miniranja",
  "Djelatnik koji obavlja poslove pripreme miniranja",
  "Djelatnik koji obavlja poslove specijalnih miniranja",
  "Djelatnik slu\u017ebe za za\u0161titu od po\u017eara",
  "Djelatnik za obavljanje poslova za\u0161tite od po\u017eara i unapre\u0111enje stanja za\u0161tite od po\u017eara",
  "Doktor dentalne medicine",
  "Doktor dentalne medicine specijalist",
  "Doktor medicine",
  "Doktor medicine specijalist",
  "Dokumentarist",
  "Dokumentarist savjetnik",
  "Do\u010dasnik",
  "Edukacijski rehabilitator",
  "Elektroinstalater",
  "Elektromehani\u010dar",
  "Elektroni\u010dar \u2013 mehani\u010dar",
  "Farmaceutski tehni\u010dar",
  "Fasader",
  "Fizioterapeutski tehni\u010dar",
  "Fotograf",
  "Frizer",
  "Galanterist",
  "Geolo\u0161ki tehni\u010dar",
  "Glavni inspektor za\u0161tite okoli\u0161a",
  "Glavni nadzornik",
  "Glazbalar",
  "Graditelj brodova",
  "Graditelj orgulja",
  "Hidrogra\u0111evinski\u00a0 inspektor",
  "Informati\u010dar",
  "Informati\u010dar savjetnik",
  "Inspektor sigurnosti unutarnje plovidbe",
  "Inspektor za\u0161tite okoli\u0161a",
  "Inspektor za\u0161tite prirode",
  "Instalater grijanja i klimatizacije",
  "Instruktor vo\u017enje",
  "In\u017eenjer geologije",
  "In\u017eenjer gradili\u0161ta",
  "In\u017eenjer medicinske radiologije",
  "In\u017eenjer medicinsko- laboratorijske dijagnostike",
  "In\u017eenjer naftnog rudarstva",
  "In\u017eenjer rudarstva",
  "Kemijski \u010dista\u010d",
  "Klesar",
  "Klobu\u010dar",
  "Knji\u017eni\u010dar",
  "Knji\u017eni\u010darski savjetnik",
  "Kondukter",
  "Kontrolor zra\u010dnog prometa",
  "Konzervator",
  "Konzervator savjetnik",
  "Konzervator tehni\u010dar",
  "Konzervator \u2013 restaurator savjetnik",
  "Konzervator \u2013\u00a0 restaurator",
  "Koordinator za\u0161tite na radu",
  "Kormilar",
  "Kotlar",
  "Kova\u010d",
  "Kozmeti\u010dar",
  "Kriminalist",
  "Kroja\u010d mu\u0161ke odje\u0107e",
  "Kroja\u010d \u017eenske odje\u0107e",
  "Krovopokriva\u010d",
  "Krznar",
  "Kuhar",
  "Kustos",
  "Lektor hrvatskog jezika na stranim visoko\u0161kolskim ustanovama",
  "Limar",
  "Ljekarnik",
  "Ljekarnik specijalist",
  "Ljeva\u010d",
  "Lovac",
  "Lovo\u010duvar",
  "Magistar sanitarnog in\u017eenjerstva",
  "Magistar sestrinstva",
  "Maser \u2013 kupeljar",
  "Medicinska sestra op\u0107e njege",
  "Medicinska sestra-medicinski tehni\u010dar",
  "Medicinska sestra/medicinski tehni\u010dar specijalist",
  "Medicinski biokemi\u010dar",
  "Medicinski biokemi\u010dar specijalist",
  "Mehani\u010dar poljoprivredne mehanizacije",
  "Mesar",
  "Mlinar",
  "Mljekar",
  "Mornar",
  "Muzejski pedagog",
  "Muzejski pedagog savjetnik",
  "Muzejski savjetnik",
  "Muzejski tehni\u010dar",
  "Nadzornik",
  "Nadzornik tehni\u010dke ispravnosti vozila",
  "Nadzornik za okoli\u0161",
  "Nastavnik predmetne nastave u srednjoj \u0161koli",
  "Natkonobar",
  "Nauti\u010dki inspektor",
  "Obu\u0107ar",
  "Ocjenjiva\u010d lova\u010dkih trofeja",
  "Odgajatelj u u\u010deni\u010dkom domu",
  "Odgojitelj djece pred\u0161kolske dobi",
  "Odgovorna osoba za ocjenjivanje sukladnosti gra\u0111evinskih proizvoda",
  "Odvjetnik",
  "Ortopedski obu\u0107ar",
  "Osoba koja provodi energetske preglede gra\u0111evina i/ili energetsko certificiranje zgrada",
  "Osoba stru\u010dno osposobljena za gospodarski ribolov",
  "Osoba stru\u010dno osposobljena za obavljanje akvakulture",
  "Osoba stru\u010dno osposobljena za uzgoj riba i drugih morskih organizama",
  "Osoblje za odr\u017eavanje\u00a0 zrakoplova (mehani\u010dari, tehni\u010dari i in\u017eenjeri)",
  "Ovla\u0161tena osoba za izradu elaborata za\u0161tite od po\u017eara",
  "Ovla\u0161teni arhitekt",
  "Ovla\u0161teni arhitekt \u2013 urbanist",
  "Ovla\u0161teni carinski slu\u017ebenik",
  "Ovla\u0161teni carinski zastupnik",
  "Ovla\u0161teni in\u017eenjer drvne tehnologije",
  "Ovla\u0161teni in\u017eenjer elektrotehnike",
  "Ovla\u0161teni in\u017eenjer geodezije",
  "Ovla\u0161teni in\u017eenjer gra\u0111evinarstva",
  "Ovla\u0161teni in\u017eenjer strojarstva",
  "Ovla\u0161teni in\u017eenjer tehnologije prometa i transporta",
  "Ovla\u0161teni in\u017eenjer \u0161umarstva",
  "Ovla\u0161teni ispitiva\u010d",
  "Ovla\u0161teni revident iz za\u0161tite od po\u017eara",
  "Ovla\u0161teni revizor",
  "Ovla\u0161teni unutarnji revizor za javni sektor",
  "O\u010dni opti\u010dar",
  "Pediker",
  "Pekar",
  "Pe\u0107ar",
  "Pirotehni\u010dar",
  "Pirotehni\u010dki nadglednik",
  "Pirotehni\u010dki nadzornik",
  "Pismoslikar",
  "Plinoinstalater",
  "Policajac",
  "Pomo\u0107ni djelatnik",
  "Pomo\u0107ni knji\u017eni\u010dar",
  "Pomo\u0107nik strojovo\u0111e",
  "Porezni savjetnik",
  "Precizni mehani\u010dar",
  "Predava\u010d",
  "Pregleda\u010d vagona",
  "Preparator",
  "Primalja",
  "Primalja \u2013 asistentica",
  "Privatni detektiv",
  "Profesionalni diplomat",
  "Profesionalni pilot aviona",
  "Profesionalni pilot helikoptera",
  "Prometni pilot aviona",
  "Prometni pilot helikoptera",
  "Prometnik vlakova",
  "Prvostupnik fizioterapije",
  "Prvostupnik medicinske radiologije",
  "Prvostupnik medicinsko- laboratorijske dijagnostike",
  "Prvostupnik primaljstva",
  "Prvostupnik radiolo\u0161ke tehnologije",
  "Prvostupnik radne terapije",
  "Prvostupnik sanitarnog in\u017eenjerstva",
  "Prvostupnik sestrinstva",
  "Prvostupnik sestrinstva specijalist",
  "Psiholog",
  "Pu\u0161kar",
  "Radio inspektor sigurnosti plovidbe",
  "Radiolo\u0161ki tehni\u010dar",
  "Radnik na stru\u010dnim poslovima na izvr\u0161enju zada\u0107a turisti\u010dke zajednice",
  "Radnik zaposlen na rukovode\u0107im poslovima",
  "Ravnatelj ustanove za pred\u0161kolski odgoj i naobrazbu",
  "Ravnatelj \u0161kolske ustanove",
  "Referent za poslove registracije vozila",
  "Restaurator",
  "Restaurator majstor",
  "Restaurator savjetnik",
  "Restaurator tehni\u010dar",
  "Revident",
  "Rudarski tehni\u010dar",
  "Rukovatelj eksplozivnim tvarima",
  "Rukovoditelj tehni\u010dkog plovila",
  "Sanitarni tehni\u010dar",
  "Sigurnosni savjetnik",
  "Slasti\u010dar",
  "Soboslikar \u2013 li\u010dilac",
  "Socijalni radnik",
  "Sportski trener",
  "Sportski u\u010ditelj / instruktor",
  "Sportski voditelj",
  "Staklar",
  "Stalni sudski procjenitelj",
  "Stalni sudski tuma\u010d",
  "Stalni sudski vje\u0161tak",
  "Stolar",
  "Strojar unutarnje plovidbe",
  "Strojobravar",
  "Strojovo\u0111a",
  "Strukovni u\u010ditelj u srednjoj \u0161koli",
  "Stru\u010dni radnik u djelatnosti socijalne skrbi",
  "Stru\u010dni radnik u ustanovi socijalne skrbi",
  "Stru\u010dni suradnik ovla\u0161tenog in\u017eenjera geodezije",
  "Stru\u010dni suradnik u pred\u0161kolskoj ustanovi",
  "Stru\u010dni suradnik u \u0161kolskoj ustanovi",
  "Stru\u010dni voditelj auto\u0161kole",
  "Stru\u010dnjak za\u0161tite na radu",
  "Suradnik ovla\u0161tenog in\u017eenjera geodezije",
  "Suradnik u nastavi",
  "Tapetar",
  "Tesar",
  "Tokar",
  "Turisti\u010dki pratitelj",
  "Turisti\u010dki vodi\u010d",
  "Upravitelj prijevoza (osoba odgovorna za prijevoz)",
  "Urar",
  "U\u010ditelj predmetne nastave u osnovnoj \u0161koli",
  "U\u010ditelj razredne nastave u osnovnoj \u0161koli",
  "U\u010ditelj stru\u010dnih predmeta",
  "Veterinar",
  "Veterinarski tehni\u010dar",
  "Vi\u0161i arhivist",
  "Vi\u0161i arhivski tehni\u010dar",
  "Vi\u0161i dokumentarist",
  "Vi\u0161i fotograf",
  "Vi\u0161i informati\u010dar",
  "Vi\u0161i inspektor",
  "Vi\u0161i inspektor cestovnog prometa i cesta",
  "Vi\u0161i inspektor za\u0161tite okoli\u0161a",
  "Vi\u0161i inspektor za\u0161tite prirode",
  "Vi\u0161i knji\u017eni\u010dar",
  "Vi\u0161i konzervator",
  "Vi\u0161i konzervator tehni\u010dar",
  "Vi\u0161i konzervator tehni\u010dar II stupnja",
  "Vi\u0161i konzervator \u2013\u00a0 restaurator",
  "Vi\u0161i kustos",
  "Vi\u0161i muzejski pedagog",
  "Vi\u0161i muzejski tehni\u010dar",
  "Vi\u0161i preparator",
  "Vi\u0161i restaurator",
  "Vi\u0161i restaurator tehni\u010dar",
  "Vlakovo\u0111a",
  "Voditelj ispostave",
  "Voditelj poslovnice turisti\u010dke agencije",
  "Voditelj projekta",
  "Voditelj radili\u0161ta",
  "Voditelj radova",
  "Voditelj skele u nacionalnoj plovidbi",
  "Vodoinstalater",
  "Vodoinstalater, instalater grijanja i klimatizacije",
  "Vojnik",
  "Voza\u010d teretnog motornog vozila i autobusa",
  "Vo\u0111a palube",
  "Zapovjednik plovila (vrsta A, vrsta B, vrsta C)",
  "Za\u0161titar",
  "Za\u0161titar-tehni\u010dar",
  "Zdravstveno laboratorijski tehni\u010dar",
  "Zidar",
  "Zlatar",
  "\u010casnik",
  "\u010clan kabinske posade zrakoplova",
  "\u010cuvar",
  "\u010cuvar prirode"
)
#' Job provider for Croatia
#'
#' @inherit JobProvider description details return
#' @family hr
#' @family HR
#' @export
#' @examples
#' x <- JobProvider_hr_HR$new()
#' x$render()
JobProvider_hr_HR <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_hr_HR",
  private = list(
    locale_ = "hr_HR",
    formats = job_formats_hr_hr
  )
)
